import WPJSBase from "../Base/WPJSBase";
import UserDataType from "../Types/Data/UserDataType";
/**
 * User class.
 *
 * @since 2.0.0
 */
export default class User extends WPJSBase<UserDataType> {
    private _userId;
    constructor(userId: number);
    /**
     * Set the user id.
     * @param userId
     *
     * @since 2.0.0
     * @description
     * This will set the user id. This is useful if you want to get posts from different users while keeping the same user instance.
     * @example
     * import {User} from "@quickdevelopment/wp-js";
     *
     * const user = new User(1);
     * user.get().then((user) => {
     *     // This will return all information from user 1.
     *     console.log(user)
     * });
     *
     * user.byUserId(2).get().then((user) => {
     *     // This will return all information from user 2.
     *     console.log(user)
     * });
     */
    byUserId(userId: number): this;
    /**
     * Get the user id.
     * @return userId
     * @since 2.0.0
     * @example
     * import {User} from "@quickdevelopment/wp-js";
     *
     * const user = new User(1);
     *
     * // This will return 1.
     * user.getUserId();
     */
    getUserId(): number;
    /**
     * Get the user data.
     * @since 2.0.0
     * @example
     * import {User} from "@quickdevelopment/wp-js";
     *
     * const user = new User(1);
     *
     * user.get().then((user) => {
     *     console.log(user)
     * })
     */
    fetch(): Promise<UserDataType>;
}
