import WPJSSingleton from "../Singleton/WPJSSingleton";
import WPJSConfigOptions from "../Types/WPJSConfigOptions";
/**
 * ConfigManager
 *
 * @description
 * ConfigManager is a singleton class that loads the config from wp-js.config.ts
 *
 * @example
 * import {ConfigManager} from "@quickdevelopment/wp-js";
 *
 * ConfigManager.getInstance({ apiUrl: 'https://api.wordpress.org/wp-json/wp/v2', embed: true });
 */
export default class ConfigManager extends WPJSSingleton {
    private readonly _config;
    private constructor();
    /**
     * Get the instance
     * @param customConfig
     * @since 1.0.0
     */
    static getInstance(customConfig?: WPJSConfigOptions): ConfigManager;
    /**
     * Get the config
     *
     * @returns {WPJSConfigOptions}
     * @example
     * import { ConfigManager } from "@quickdevelopment/wp-js";
     *
     * const config = ConfigManager.getInstance();
     *
     * // It will return your earlier provided config
     * console.log(config.getConfig());
     */
    getConfig(): WPJSConfigOptions;
    /**
     * Load the config
     * @param customConfig
     * @private
     */
    private loadConfig;
}
